<template>
  <div class="app-container">
    <div class="search_form">
      <div>
        <span class="search_title">供应商名称/合同号：</span>
        <el-input v-model="searchForm.supplierNameOrContractNo" style="width: 240px" placeholder="输入供应商名称/合同号搜索"
          @change="handleQuery" clearable :prefix-icon="Search" />
        <el-button type="primary" @click="handleQuery" style="margin-left: 10px">搜索</el-button>
      </div>
      <div>
        <el-button type="primary" @click="openForm('add')">新增付款</el-button>
        <el-button type="danger" plain @click="handleDelete">删除</el-button>
      </div>
    </div>
    <div class="table_list">
      <PIMTable :column="tableColumn" :tableData="tableData" :page="page" :isSelection="true"
        :handleSelectionChange="handleSelectionChange" :tableLoading="tableLoading" @pagination="pagination"
        :total="total"></PIMTable>
    </div>
    <el-dialog v-model="dialogFormVisible" :title="operationType === 'add' ? '新增付款登记' : '编辑付款登记'" width="60%"
      @close="closeDia">
      <el-form :model="form" label-width="140px" label-position="top" :rules="rules" ref="formRef">
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="采购合同号：" prop="purchaseLedgerId">
              <el-select v-model="form.purchaseLedgerId" placeholder="请选择" clearable @change="setInfo"
                :disabled="operationType === 'edit'">
                <el-option v-for="item in purchaseLedgerList" :key="item.id" :label="item.purchaseContractNumber"
                  :value="item.id" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="销售合同号：" prop="salesContractNo">
              <el-input v-model="form.salesContractNo" placeholder="自动填充" clearable disabled />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="供应商名称：" prop="supplierName">
              <el-input v-model="form.supplierName" placeholder="自动填充" clearable disabled />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="发票号：" prop="invoiceNumber">
              <el-select v-model="form.invoiceNumber" placeholder="请选择" clearable :disabled="operationType === 'edit'"
                @change="setInvoiceAmount">
                <el-option v-for="item in invoiceNumberList" :key="item.id" :label="item.invoiceNumber"
                  :value="item.invoiceNumber" />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="发票金额(元)：" prop="invoiceAmount">
              <el-input type="number" :step="0.01" v-model="form.invoiceAmount" placeholder="自动填充" clearable disabled />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="税率(%)：" prop="taxRate">
              <!-- <el-input type="number" :step="0.01" v-model="form.taxRate" placeholder="自动填充" clearable/> -->
              <el-select v-model="form.taxRate" placeholder="请选择" clearable :disabled="operationType === 'edit'">
                <el-option v-for="item in taxRateSelection" :key="item.value" :label="item.label" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="本次付款金额：" prop="currentPaymentAmount">
              <el-input type="number" :step="0.01" v-model="form.currentPaymentAmount" placeholder="请输入" clearable />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="付款方式：" prop="paymentMethod">
              <el-select v-model="form.paymentMethod" placeholder="请选择" clearable>
                <el-option label="电汇" value="电汇" />
                <el-option label="承兑" value="承兑" />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="登记人：" prop="registrant">
              <el-input v-model="form.registrant" placeholder="请输入" clearable disabled />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="付款日期：" prop="paymentDate">
              <el-date-picker disabled style="width: 100%" v-model="form.paymentDate" value-format="YYYY-MM-DD"
                format="YYYY-MM-DD" type="date" placeholder="请选择" clearable />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="登记日期：" prop="registrationtDate">
              <el-input v-model="form.registrationtDate" placeholder="请输入" clearable disabled />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确认</el-button>
          <el-button @click="closeDia">取消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup>
import { ref } from 'vue'
import { Search } from "@element-plus/icons-vue";
import { ElMessageBox } from "element-plus";
import { getInfo } from "@/api/login.js";
import useUserStore from "@/store/modules/user.js";
import {
  byPurchaseId,
  getPurchaseNo,
  paymentRegistrationAdd, paymentRegistrationDel,
  paymentRegistrationEdit,
  registrationInfo,
  registrationList,
  getTicketNo
} from "@/api/procurementManagement/paymentEntry.js";
const { proxy } = getCurrentInstance()
const taxRateSelection = [
  { value: '0', label: '0%' },
  { value: '3', label: '3%' },
  { value: '6', label: '6%' },
  { value: '9', label: '9%' },
  { value: '13', label: '13%' },
  { value: '17', label: '17%' },
]
const tableColumn = ref([
  {
    label: '采购合同号',
    prop: 'purchaseContractNumber',
  },
  {
    label: '销售合同号',
    prop: 'salesContractNo',
  },
  {
    label: '供应商名称',
    prop: 'supplierName',
  },
  {
    label: '发票号',
    prop: 'invoiceNumber'
  },
  {
    label: '发票金额(元)',
    prop: 'invoiceAmount'
  },
  {
    label: '本次付款金额(元)',
    prop: 'currentPaymentAmount'
  },
  {
    label: '待付款金额(元)',
    prop: 'unPaymentAmount'
  },
  {
    dataType: "action",
    label: "操作",
    align: 'center',
    operation: [
      {
        name: "编辑",
        type: "text",
        clickFun: (row) => {
          openForm('edit', row);
        },
      },
    ],
  },
])
const tableData = ref([])
const selectedRows = ref([])
const tableLoading = ref(false)
const purchaseLedgerList = ref([])
const invoiceNumberList = ref([])
const userStore = useUserStore()
const page = reactive({
  current: 1,
  size: 10,
})
const total = ref(0)

// 用户信息表单弹框数据
const operationType = ref('')
const dialogFormVisible = ref(false)
const data = reactive({
  searchForm: {
    supplierNameOrContractNo: '',
  },
  form: {
    purchaseLedgerId: '',
    salesContractNo: '',
    supplierName: '',
    invoiceNumber: '',
    invoiceAmount: '',
    taxRate: '',
    currentPaymentAmount: '',
    paymentMethod: '',
    registrant: '',
    registrantId: '',
    paymentDate: '',
    registrationtDate: "",
  },
  rules: {
    purchaseLedgerId: [{ required: true, message: "请选择", trigger: "change" }],
    currentPaymentAmount: [{ required: true, message: "请输入", trigger: "blur" }],
    paymentMethod: [{ required: true, message: "请选择", trigger: "change" }],
    invoiceNumber: [{ required: true, message: "请选择采购合同号", trigger: "change" }],
  }
})
const { searchForm, form, rules } = toRefs(data)

// 查询列表
/** 搜索按钮操作 */
const handleQuery = () => {
  page.current = 1
  getList()
}
const pagination = ({ current, limit }) => {
  page.current = current;
  page.size = limit;
  getList()
}
const getList = () => {
  tableLoading.value = true
  registrationList({ ...searchForm.value, ...page }).then(res => {
    tableLoading.value = false
    tableData.value = res.rows
    total.value = res.total
  })
}
// 表格选择数据
const handleSelectionChange = (selection) => {
  selectedRows.value = selection
}
// 打开弹框
const openForm = (type, row) => {
  operationType.value = type
  form.value = {}
  invoiceNumberList.value = []
  // 查询采购合同号
  getPurchaseNo().then(res => {
    purchaseLedgerList.value = res
  })
  form.value.registrationtDate = getCurrentDate();
  form.value.paymentDate = getCurrentDate();
  form.value.registrant = userStore.name
  if (type === 'edit') {
    registrationInfo(row.id).then(res => {
      form.value = { ...res.data }
      if (form.value.registrantId == userStore.id) {
        form.value.registrant = userStore.name
      }
    })
  }
  dialogFormVisible.value = true
}
// 选择发票号以后给发票金额赋值
const setInvoiceAmount = (value) => {
  if (value) {
    invoiceNumberList.value.forEach(item => {
      if (item.invoiceNumber === value) {
        form.value.invoiceAmount = item.invoiceAmount
        form.value.ticketRegistrationId = item.id
      }
    })
  } else {
    form.value.invoiceAmount = ''
  }
}
// 选择采购合同号赋值
const setInfo = (value) => {
  getTicketNo({ id: value }).then((res) => {
    invoiceNumberList.value = res.data
  })
  if (value) {
    byPurchaseId(value).then(res => {
      form.value.salesContractNo = res.data.salesContractNo
      form.value.supplierName = res.data.supplierName
      form.value.taxRate = res.data.taxRate
      form.value.supplierId = res.data.supplierId
    })
  } else {
    form.value.salesContractNo = ''
    form.value.supplierName = ''
    form.value.taxRate = ''
    form.value.supplierId = ''
  }
}
// 提交表单
const submitForm = () => {
  proxy.$refs["formRef"].validate(valid => {
    if (valid) {
      if (operationType.value === "edit") {
        submitEdit()
      } else {
        submitAdd()
      }
    }
  })
}
// 提交新增
const submitAdd = () => {
  paymentRegistrationAdd(form.value).then(res => {
    proxy.$modal.msgSuccess("提交成功")
    closeDia()
    getList()
  })
}
// 提交修改
const submitEdit = () => {
  paymentRegistrationEdit(form.value).then(res => {
    proxy.$modal.msgSuccess("提交成功")
    closeDia()
    getList()
  })
}
// 关闭弹框
const closeDia = () => {
  proxy.resetForm("formRef")
  dialogFormVisible.value = false
}
// 删除
const handleDelete = () => {
  let ids = []
  if (selectedRows.value.length > 0) {
    ids = selectedRows.value.map(item => item.id);
  } else {
    proxy.$modal.msgWarning('请选择数据')
    return
  }
  ElMessageBox.confirm(
    '选中的内容将被删除，是否确认删除？',
    '删除提示', {
    confirmButtonText: '确认',
    cancelButtonText: '取消',
    type: 'warning',
  }
  ).then(() => {
    tableLoading.value = true
    paymentRegistrationDel(ids).then(res => {
      proxy.$modal.msgSuccess("删除成功")
      getList()
    }).finally(() => {
      tableLoading.value = false
    })
  }).catch(() => {
    proxy.$modal.msg("已取消")
  })
}
// 获取当前日期并格式化为 YYYY-MM-DD
function getCurrentDate() {
  const today = new Date();
  const year = today.getFullYear();
  const month = String(today.getMonth() + 1).padStart(2, '0'); // 月份从0开始
  const day = String(today.getDate()).padStart(2, '0');
  return `${year}-${month}-${day}`;
}
getList()
</script>

<style scoped lang="scss"></style>
